<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="nb">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valgfri</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Koble fra</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Kobler til</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Koble fra</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Kablet Forbindelse %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Trådløs Forbindelse %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Forbindelse %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Ny VPN forbindelse</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN-type </translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>ÅpenTilkobling </translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSWAN
</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksporter</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Nettverksdetaljer</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablet Nettverk</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst nettverk</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Legge til nettverkstilkobling</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Koble til skjult nettverk</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Opprett PPPoE-forbindelse</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Opprett VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importer VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurasjons URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Grensesnitt</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Bånd</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primær DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Nettmaske</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighet</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ikke Bind</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enhet MAC adr</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klonet MAC adr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Tilpass MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Generel</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Generel</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Legg til innstillinger</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Nettmaske</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-adresse</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Method</source>
        <translation>Metode</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Nettmaske</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metode</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Nettverksdetaljer</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Nettverksdetaljer</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiver  </translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Tjeneste </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Nekte EAP-godkjenning</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Nekte PAP-godkjenning</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Nekte CHAP Godkjenning</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Nekte MSCHAP Godkjenning</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Nekte MSCHAPv2 Godkjenning</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ingen BSD datakomprimering</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ingen Deflate datakomprimering</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ingen TCP hodekomprimering</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ingen Protocol Felt Kompresjon</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ingen Adresse/Kontroll Komprimering</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP Echo Pakker</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Bruk MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Opprett PPPoE-forbindelse</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Valgfri</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorer proxykonfigurasjonen for overstående verter og domener</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurasjons URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Sikkerhet</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>tlS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FORT</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunnelert TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Beskyttet EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiver  </translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonoym</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autentisert</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Begge</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versjon 1</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versjon 2</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Autentikasjon </translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitet </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Valg</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nøkkel</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Bruker Cert</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonym ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Klargjøring  </translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC fil</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Indre Auth</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP Versjon </translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat Pass</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personlig</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Nøkkel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Sikkerhet Påkrevd</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personlig</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Bedrift</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>Nøkkel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avansert</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Tilpass Gateway Port</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gateway Port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Tilpass Reforhandling Interval</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Reforhandlings Intervall</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tilpass Tunnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Tilpass UDP Fragment Størrelse</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Fragment Størrelse</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Begrense Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Tilfeldig eksterne verter</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avansert</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (standard)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netskjerm</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Sikre (standard)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Sva</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Når tilgjengelig (standard)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Alltid</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiver  </translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Gruppe 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Gruppe 2 (standard)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Gruppe 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (standard)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Gruppe 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domene</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Leverandør</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versjon</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Kryptering</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal Mode</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Gruppe</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokal Port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Deaktivere Døde Peer Deteksjon</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Aktiver IPsek</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppe Navn</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Gruppe ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>For-håndsdelt Nøkkel </translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 Algoritmer</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 Algoritmer</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Tillat Cisco Sikker Skrivebord Trojan </translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Bruker Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nøkkel</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Bruk FSID for Nøkkel Passord</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sertifikater (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Sertifikater med passord (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statisk nøkkel</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Lagret</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Spørre</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrevd</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Autentikasjon Type</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Bruker Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nøkkel</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Valg</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privat Pass</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Tilpass Nøkkel Retning</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Nøkkel Retning </translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Fjern IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokal IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Alle tilgjengelige (standard)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (mindre sikkert)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (sikkrest)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Nekte EAP-godkjenning</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Nekte PAP-godkjenning</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Nekte CHAP Godkjenning</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Nekte MSCHAP Godkjenning</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Nekte MSCHAPv2 Godkjenning</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Ingen BSD datakomprimering</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Ingen Deflate datakomprimering</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Ingen TCP hodekomprimering</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Ingen Protocol Felt Kompresjon</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ingen Adresse/Kontroll Komprimering</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP Echo Pakker</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Bruk MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhet</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Opprett VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importer VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Import feilet</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrevd</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxytype</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Prøv på nytt i ubestemt tid Når Mislyktes</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA Fil</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN Sikkerhet</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Lagret</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Spørre</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrevd</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Valg</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Domene</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server-IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privat Nøkkel</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>For-håndsdelt Nøkkel </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Autentikasjon Type</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Bruker Cert</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Forespør en indre IP-addresse</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Påtving UDP-innkapsling</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Bruk IP-komprimering</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Autentisering</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subject Match</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Remote Cert Type</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Nøkkel Fil</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Tilpass Nøkkel Retning</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Nøkkel Retning </translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Lagret</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Spørre</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Ikke påkrevd</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Valg</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Gruppe Navn</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Gruppe Pass</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Bruk Hybrid Autentikasjon </translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA Fil</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Legge til nettverkstilkobling</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Velg innstillinger</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Lukk Hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Koble til skjult nettverk</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ikke Bind</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Påkrevd</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Enhet MAC adr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Tilpass MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>